@@ -2041,9 +2041,7 @@ netk_task_state_changed (NetkWindow * window, NetkWindowState changed_mask,
             if(new_state & NETK_WINDOW_STATE_URGENT)
             {
                 win_task->blink_timeout_id = 
-                                       g_timeout_add (500, 
-                                                      urgent_timeout_callback, 
-                                                      win_task);
+                    g_timeout_add (500, urgent_timeout_callback, win_task);
             }
             else 
             {
