@@ -46,8 +46,7 @@
 
 #define VALID_KDEDIR g_getenv("KDEDIR") && strlen(g_getenv("KDEDIR"))
 #define KDEDIR g_getenv("KDEDIR"),"share","icons"
-/*#define HOMEDIR xfce_get_homedir(), ".icons"*/
-#define HOMEDIR  ".icons"
+#define HOMEDIR  g_get_home_dir(),".icons"
 #define SERIAL 41911
 
 /* get rid of warnings generated on FreeBSD.5.2.1 
@@ -773,36 +772,47 @@ add2cache(gpointer key, gpointer value, gpointer user_data)
 }
 
 typedef struct cache_info_t {
-    int basedir_sum;
+    long long basedir_sum;
     gchar supported_regex[256];
 } cache_info_t;
 
+static long long get_basedir_sum(void){
+    long long basedir_sum=0;
+    GList *list;
+    for (list=base_dirs;list;list=list->next){
+	struct stat st;
+	if (stat((gchar *)list->data,&st)==0) {
+	    TRACE("stat ok");
+	    basedir_sum += st.st_mtime;
+	    basedir_sum += st.st_dev;
+	}
+	TRACE("summing %s (%d %d)",(gchar *)list->data,st.st_mtime,st.st_dev);
+    }
+   basedir_sum +=SERIAL;
+   return basedir_sum;
+}
+
 static 
 void
 save_cache_info(gchar *theme, int size){
     FILE *info;
     gchar *cache_info_path=g_strconcat(cache_file,".info",NULL);
     cache_info_t cache_info;
-    GList *list;
     if (!cache_file) return;
     cache_info_path=g_strconcat(cache_file,".info",NULL);
     TRACE("saving %s",cache_info_path);
-    cache_info.basedir_sum=0;
-    for (list=base_dirs;list;list=list->next){
-	struct stat st;
-	if (stat((gchar *)list->data,&st)==0) {
-	    cache_info.basedir_sum += st.st_mtime;
-	    cache_info.basedir_sum += st.st_dev;
-	}
-    }
-    cache_info.basedir_sum +=SERIAL;
+    
+    cache_info.basedir_sum=get_basedir_sum();
     strncpy(cache_info.supported_regex,get_supported_regex(),255);
     cache_info.supported_regex[255]=0;
     info=fopen(cache_info_path,"wb");
     if (info) {
-	fwrite(&cache_info,sizeof(cache_info_t),1,info);
+	if (fwrite(&cache_info,sizeof(cache_info_t),1,info)<1){
+	    g_warning("cannot write to %s",cache_info_path);
+	}
 	fclose(info);
-    }
+    } else g_warning("cannot write to %s",cache_info_path);
+    TRACE("wrote basedir sum is %lld",cache_info.basedir_sum);
     g_free(cache_info_path);
 }
 
@@ -819,16 +829,16 @@ compare_cache_info(gchar *theme, int size){
     FILE *info;
     gchar *cache_info_path;
     cache_info_t cache_info,disk_cache_info;
-    GList *list;
+	
 
     if (!g_file_test(cache_file,G_FILE_TEST_EXISTS)) {
-	TRACE("%s not exists",cache_file);
+	DBG("%s not exists",cache_file);
 	return FALSE;
     }
     
     cache_info_path=g_strconcat(cache_file,".info",NULL);
     if ((info=fopen(cache_info_path,"rb"))==NULL){
-	TRACE("%s not exists",cache_info_path);
+	DBG("%s not exists",cache_info_path);
 	g_free(cache_info_path);
 	return FALSE;
     }
@@ -836,25 +846,18 @@ compare_cache_info(gchar *theme, int size){
     
     fread(&disk_cache_info,sizeof(cache_info_t),1,info);
     fclose(info);
+    TRACE("read basedir sum is %lld",disk_cache_info.basedir_sum);
     
-    cache_info.basedir_sum=0;
-    for (list=base_dirs;list;list=list->next){
-	struct stat st;
-	if (stat((gchar *)list->data,&st)==0) {
-	    cache_info.basedir_sum += st.st_mtime;
-	    cache_info.basedir_sum += st.st_dev;
-	}
-    }
-    cache_info.basedir_sum += SERIAL;
+    cache_info.basedir_sum=get_basedir_sum();
     if (cache_info.basedir_sum != disk_cache_info.basedir_sum) {
-	TRACE("cache_info.basedir_sum(%d) != disk_cache_info.basedir_sum(%d)",cache_info.basedir_sum, disk_cache_info.basedir_sum);
+	DBG("cache_info.basedir_sum(%lld) != disk_cache_info.basedir_sum(%lld)",cache_info.basedir_sum, disk_cache_info.basedir_sum);
 	return FALSE;
     }
     
     strncpy(cache_info.supported_regex,get_supported_regex(),255);
     cache_info.supported_regex[255]=0;
     if (strcmp(cache_info.supported_regex,disk_cache_info.supported_regex)) {
-	TRACE("cache_info.supported_regex != disk_cache_info.supported_regex");
+	DBG("cache_info.supported_regex != disk_cache_info.supported_regex");
 	return FALSE;
     }
     return TRUE;
